@@ -536,7 +536,7 @@ list_to_string (const GValue *src, GValue *dest)
 	gchar *str;
 	const GdaValueList *list;
 	GList *l;
-	GString *gstr;
+	GString *gstr = NULL;
 	
 	g_return_if_fail (G_VALUE_HOLDS_STRING (dest) &&
 			  GDA_VALUE_HOLDS_LIST (src));
@@ -544,20 +544,16 @@ list_to_string (const GValue *src, GValue *dest)
 	list = gda_value_get_list ((GValue *) src);
 	
 	for (l = (GList *) list; l != NULL; l = l->next) {
-		gchar *s;
-
-		s = gda_value_stringify ((GValue *) l->data);
-		if (!str) {
-			gstr = g_string_new ("{ \"");
-			gstr = g_string_append (gstr, s);
-			gstr = g_string_append (gstr, "\"");
+		str = gda_value_stringify ((GValue *) l->data);
+		if (!gstr) {
+			gstr = g_string_new ("{ ");
+			gstr = g_string_append (gstr, str);
 		}
 		else {
-			gstr = g_string_append (gstr, ", \"");
-			gstr = g_string_append (gstr, s);
-			gstr = g_string_append (gstr, "\"");
+			gstr = g_string_append (gstr, ", ");
+			gstr = g_string_append (gstr, str);
 		}
-		g_free (s);
+		g_free (str);
 	}
 
 	if (gstr) {
@@ -1749,6 +1745,26 @@ gda_value_stringify (const GValue *value)
 				else
 					return g_strdup ("0000-00-00");
 			}
+			else if (type == GDA_TYPE_LIST) {
+				GdaValueList *list;
+				GList *ptr;
+				GString *string;
+				gchar *tmp;
+
+				string = g_string_new ("[");
+				list = gda_value_get_list (value);
+				for (ptr = list; ptr; ptr = ptr->next) {
+					tmp = gda_value_stringify ((GValue *) ptr->data);
+					if (ptr != list)
+						g_string_append_c (string, ',');
+					g_string_append (string, tmp);
+					g_free (tmp);
+				}
+				g_string_append_c (string, ']');
+				tmp = string->str;
+				g_string_free (string, FALSE);
+				return tmp;
+			}
 			else
 				return g_strdup ("");
 		}
@@ -1806,9 +1822,13 @@ gda_value_compare (const GValue *value1, const GValue *value2)
 	else if (type == GDA_TYPE_BLOB) {
 		const GdaBlob *blob1 = gda_value_get_blob (value1);
 		const GdaBlob *blob2 = gda_value_get_blob (value2);
-		if (blob1 && blob2 && (((GdaBinary *)blob1)->binary_length == ((GdaBinary *)blob2)->binary_length))
-			return memcmp (((GdaBinary *)blob1)->data, ((GdaBinary *)blob2)->data, 
-				       ((GdaBinary *)blob1)->binary_length) ;
+		if (blob1 && blob2 && (((GdaBinary *)blob1)->binary_length == ((GdaBinary *)blob2)->binary_length)) {
+			if (blob1->op == blob2->op)
+				return memcmp (((GdaBinary *)blob1)->data, ((GdaBinary *)blob2)->data, 
+					       ((GdaBinary *)blob1)->binary_length);
+			else
+				return -1;
+		}
 		else
 			return -1;
 	}
